==> jc-1.4.0.tar.gz: jas/FloatCP.h <==
// public class jas.FloatCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class f46b5750387a0fc3 jas_FloatCP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_FloatCP_H_
#define _JC_jas_FloatCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_FloatCP$sub_refs	_jc_jas_FloatCP$sub_refs;
typedef struct _jc_jas_FloatCP$sub_nonrefs	_jc_jas_FloatCP$sub_nonrefs;
typedef struct _jc_jas_FloatCP$refs	_jc_jas_FloatCP$refs;
typedef struct _jc_jas_FloatCP$nonrefs	_jc_jas_FloatCP$nonrefs;
typedef struct _jc_jas_FloatCP$object	_jc_jas_FloatCP$object;

typedef const struct _jc_jas_FloatCP$vmethods	_jc_jas_FloatCP$vmethods;
typedef const struct _jc_jas_FloatCP$vtable	_jc_jas_FloatCP$vtable;
typedef const struct _jc_jas_FloatCP$vtype	_jc_jas_FloatCP$vtype;

// Constructors
extern void _jc_jas_FloatCP$method$_init$6641b0bc5c619f68(_jc_env *, struct _jc_jas_FloatCP$object *, jfloat);

// Virtual methods
extern void _jc_jas_FloatCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_FloatCP$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_FloatCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_FloatCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_FloatCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_FloatCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_FloatCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_FloatCP$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_FloatCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_FloatCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_FloatCP$vmethods	jas_FloatCP;
};

// Vtype
struct _jc_jas_FloatCP$vtype {
	_jc_type			type;
	_jc_jas_FloatCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_FloatCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_FloatCP$refs {
    _jc_jas_FloatCP$sub_refs	jas_FloatCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_FloatCP$sub_nonrefs {
	jfloat	val;
};

// Non-reference instance fields (object)
struct _jc_jas_FloatCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_FloatCP$sub_nonrefs	jas_FloatCP;
};

// Object instance structure
struct _jc_jas_FloatCP$object {
	_jc_jas_FloatCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_FloatCP$vtype	*vtype;
	_jc_jas_FloatCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_FloatCP$vtype _jc_jas_FloatCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_FloatCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_FloatCP$class_object;

#endif	/* _JC_jas_FloatCP_H_ */

==> jc-1.4.6.tar.gz: jas/FloatCP.h <==
// public class jas.FloatCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class f46b5750387a0fc3 jas_FloatCP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_FloatCP_H_
#define _JC_jas_FloatCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_FloatCP$sub_refs	_jc_jas_FloatCP$sub_refs;
typedef struct _jc_jas_FloatCP$sub_nonrefs	_jc_jas_FloatCP$sub_nonrefs;
typedef struct _jc_jas_FloatCP$refs	_jc_jas_FloatCP$refs;
typedef struct _jc_jas_FloatCP$nonrefs	_jc_jas_FloatCP$nonrefs;
typedef struct _jc_jas_FloatCP$object	_jc_jas_FloatCP$object;

typedef const struct _jc_jas_FloatCP$vmethods	_jc_jas_FloatCP$vmethods;
typedef const struct _jc_jas_FloatCP$vtable	_jc_jas_FloatCP$vtable;
typedef const struct _jc_jas_FloatCP$vtype	_jc_jas_FloatCP$vtype;

// Constructors
extern void _jc_jas_FloatCP$method$_init$6641b0bc5c619f68(_jc_env *, struct _jc_jas_FloatCP$object *, jfloat) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_FloatCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_FloatCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_FloatCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_FloatCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_FloatCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_FloatCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_FloatCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_FloatCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_FloatCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_FloatCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_FloatCP$vmethods	jas_FloatCP;
};

// Vtype
struct _jc_jas_FloatCP$vtype {
	_jc_type			type;
	_jc_jas_FloatCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_FloatCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_FloatCP$refs {
    _jc_jas_FloatCP$sub_refs	jas_FloatCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_FloatCP$sub_nonrefs {
	jfloat	val;
};

// Non-reference instance fields (object)
struct _jc_jas_FloatCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_FloatCP$sub_nonrefs	jas_FloatCP;
};

// Object instance structure
struct _jc_jas_FloatCP$object {
	_jc_jas_FloatCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_FloatCP$vtype	*vtype;
	_jc_jas_FloatCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_FloatCP$vtype _jc_jas_FloatCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_FloatCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_FloatCP$class_object;

#endif	/* _JC_jas_FloatCP_H_ */
